<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 06/10/2005 *
 * ===================                          Last change: 05/18/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-sponsor_reg.php                             *
 * -------------------------------------------------------------------- *
 * Short description : Sponsor's registration form                      *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Anmeldeformular fuer Sponsoren                   *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('guest', __FILE__);

if ((!isExtensionActive('sponsor'))) {
	displayMessage(generateExtensionInactiveNotInstalledMessage('sponsor'));
	return;
} // END - if

// Create array for form errors (= missing data)
$formErrors = array();

if (isFormSent()) {
	//
	// Check submitted form data
	//
	// 1. Salutation / Surname / family name
	if (!isPostRequestParameterSet('gender')) {
		// Surname is empty
		$formErrors[] = '{--SPONSOR_NO_GENDER_SELECTED--}';
	} // END - if

	if (!isPostRequestParameterSet('surname')) {
		// Surname is empty
		$formErrors[] = '{--SPONSOR_SURNAME_IS_EMPTY--}';
	} // END - if

	if (!isPostRequestParameterSet('family')) {
		// Surname is empty
		$formErrors[] = '{--SPONSOR_FAMILY_IS_EMPTY--}';
	} // END - if

	// 2. Company name
	// 012                          3         32    23                         4           43    3                         4          4321    12                         3         32    2                          3           3210
	if (((!isPostRequestParameterSet('company')) && ((isPostRequestParameterSet('tax_ident')) || (isPostRequestParameterSet('position')))) || ((isPostRequestParameterSet('company')) && (!isPostRequestParameterSet('tax_ident')))) {
		if (!isPostRequestParameterSet('company')) {
			// Company name is empty
			$formErrors[] = '{--SPONSOR_COMPANY_IS_EMPTY--}';
		} elseif (!isPostRequestParameterSet('tax_ident')) {
			// Tax ident number name is empty
			$formErrors[] = '{--SPONSOR_TAX_IDENT_IS_EMPTY--}';
		}

		if (!isPostRequestParameterSet('position')) {
			// Not fatal but not nice: position in company is empty
			$formErrors[] = '{--SPONSOR_POSITION_IS_EMPTY--}';
		} // END - if
	} // END - if

	// 3. Street and number
	if (!isPostRequestParameterSet('street_nr1')) {
		// Street name and house number are empty
		$formErrors[] = '{--SPONSOR_STREET_NR1_IS_EMPTY--}';
	} elseif ((isPostRequestParameterSet('street_nr2')) && (!isPostRequestParameterSet('street_nr1'))) {
		// 1st line for street is empty, but 2nd line not
		$formErrors[] = '{--SPONSOR_STREET_NR1_IS_EMPTY_2_NOT--}';
	}

	// 4. Country code
	if (!isPostRequestParameterSet('country')) {
		// Country code is empty
		$formErrors[] = '{--kSPONSOR_COUNTRY_IS_EMPTY--}';
	} elseif (strlen(postRequestParameter('country')) != 2) {
		// Country code is invalid
		$formErrors[] = '{--SPONSOR_COUNTRY_IS_INVALID--}';
	}

	// 3. ZIP code
	if (!isPostRequestParameterSet('zip')) {
		// ZIP code is empty
		$formErrors[] = '{--SPONSOR_ZIP_IS_EMPTY--}';
	} elseif (bigintval(postRequestParameter('zip')) != postRequestParameter('zip')) {
		// ZIP is invalid
		$formErrors[] = '{--SPONSOR_ZIP_IS_INVALID--}';
		setPostRequestParameter('zip', '');
	}

	// 4. City
	if (!isPostRequestParameterSet('city')) {
		// City is empty
		$formErrors[] = '{--SPONSOR_CITY_IS_EMPTY--}';
	} // END - if

	// 5. Phone number
	if (!isPostRequestParameterSet('phone')) {
		// City is empty
		$formErrors[] = '{--SPONSOR_PHONE_IS_EMPTY--}';
	} // END - if

	// 6. Homepage URL
	if (!isPostRequestParameterSet('url')) {
		// Homepage URL is empty
		$formErrors[] = '{--SPONSOR_URL_IS_EMPTY--}';
	} elseif (!isUrlValid(postRequestParameter('url'))) {
		// Homepage URL is invalid
		$formErrors[] = '{--SPONSOR_URL_IS_INVALID--}';
		setPostRequestParameter('url', '');
	}

	// 7. Light validation of email address
	if ((!isPostRequestParameterSet('email')) || (postRequestParameter('email') == '@')) {
		// Email is invalid/empty
		$formErrors[] = '{--SPONSOR_EMAIL_IS_INVALID--}';
	} elseif (isSponsorRegisteredWithEmail(postRequestParameter('email'))) {
		// Email already found in database!
		$formErrors[] = '{--SPONSOR_EMAIL_IS_ALREADY_REGISTERED--}';
		setPostRequestParameter('email', '');
	}

	// 8. Pay type selected?
	if (!isPostRequestParameterSet('pay_type')) {
		// Not pay type selected
		$formErrors[] = '{--SPONSOR_NO_PAYTYPE_SELECTED--}';
	} // END - if

	// 9. Interval of mails
	if (!isPostRequestParameterSet('warning_interval')) {
		// No warning interval selected
		$formErrors[] = '{--SPONSOR_NO_WARNING_INTERVAL_SELECTED--}';
	} // END - if

	// 10. Mail notifications disabled/enabled
	if (!isPostRequestParameterSet('receive_warnings')) {
		// Option not selected!
		$formErrors[] = '{--SPONSOR_NO_RECEIVE_WARNINGS_SELECTED--}';
	} // END - if

	// Did he enter his password twice?
	if (((!isPostRequestParameterSet('pass1')) || (!isPostRequestParameterSet('pass2'))) || ((postRequestParameter('pass1') != postRequestParameter('pass2')) && (isPostRequestParameterSet('pass1')) && (isPostRequestParameterSet('pass2')))) {
		if ((postRequestParameter('pass1') != postRequestParameter('pass2')) && (isPostRequestParameterSet('pass1')) && (isPostRequestParameterSet('pass2'))) {
			// Passwords missmatch
			$formErrors[] = '{--SPONSOR_PASSWORDS_MISMATCH--}';
		} else {
			if (!isPostRequestParameterSet('pass1')) {
				// Password 1 is empty
				$formErrors[] = '{--SPONSOR_PASSWORD1_EMPTY--}';
			}

			if (!isPostRequestParameterSet('pass2')) {
				// Password 2 is empty
				$formErrors[] = '{--SPONSOR_PASSWORD2_EMPTY--}';
			}
		}
	} elseif (strlen(postRequestParameter('pass1')) < getPassLen()) {
		// Password is to short!
		$formErrors[] = '{--SPONSOR_PASSWORD_TOO_SHORT--}';
	}

	// Check if he has accepted the terms&conditions
	if (!isPostRequestParameterSet('terms')) {
		// Homepage URL is empty
		$formErrors[] = '{--SPONSOR_TERMS_NOT_ACCEPTED--}';
	} // END - if

	// If there is something wrong/missing stop registration
	if (count($formErrors) > 0) unsetPostRequestParameter('ok');
} // END - if

if ((isFormSent()) && (count($formErrors) == 0)) {
	// Generate message array
	$messageArray = array(
		'failed' => '{--SPONSOR_REGISTRATION_FAILED--}',
		'added'  => '{--SPONSOR_REGISTRATION_COMPLETED--}',
	);

	// Calulate points
	$result = SQL_QUERY_ESC("SELECT
	(`pay_rate` * `pay_min_count`) AS points, `pay_min_count` AS pay, `pay_currency` AS curr
FROM
	`{?_MYSQL_PREFIX?}_sponsor_paytypes`
WHERE
	`id`=%s
LIMIT 1",
		array(postRequestParameter('pay_type')), __FILE__, __LINE__);
	list($points, $pay, $curr) = SQL_FETCHROW($result);

	// Free memory
	SQL_FREERESULT($result);

	// Add points to array
	postRequestParameter('points_amount', $points);
	postRequestParameter('points_used'  , '0.00000');
	postRequestParameter('last_payment' , $pay);
	postRequestParameter('last_currency', $curr);

	// Register sponsor but never ever update here!
	$message = doProcessSponsorFormRequest($messageArray);

	// Display message
	displayMessage($message);
} else {
	// Check for payment types
	$result = SQL_QUERY('SELECT
	`id`, `pay_name`, `pay_rate`, `pay_currency`, `pay_min_count`
FROM
	`{?_MYSQL_PREFIX?}_sponsor_paytypes`
ORDER BY 
	`pay_name` ASC', __FILE__, __LINE__);
	if (!SQL_HASZERONUMS($result)) {
		// Load all types...
		$OUT = '';
		while ($content = SQL_FETCHARRAY($result)) {
			// Prepare content for output
			$content['res'] = translateComma($content['pay_rate'] * $content['pay_min_count']);

			// Load row template and switch color
			$OUT .= loadTemplate('guest_sponsor_payment_row', true, $content);
		} // END - while

		// Remember the list in table
		$content['payment_list'] = loadTemplate('guest_sponsor_payment', true, $OUT);

		// Init a lot array elements
		foreach (array('company','position','tax_ident','gender_m','gender_f','gender_c','surname','family','street_nr1','street_nr2','country','zip','city','phone','fax','cell','email','url','receive_warnings_y','receive_warnings_n','form_errors','refid') as $entry) {
			$content[$entry]   = '';
		} // END - foreach

		// Check for invalid entries
		if (count($formErrors) > 0) {
			// Some found... :-(
			foreach (array('company','position','tax_ident','surname','family','street_nr1','street_nr2','country','zip','city','phone','fax','cell','email','url') as $entry) {
				$content[$entry]    = secureString(postRequestParameter($entry));
			} // END - foreach

			// Init gender
			foreach (array('m', 'f', 'c') as $gender) {
				$content['gender_' . $gender] = '';
			} // END - foreach

			// Check for gender selection
			$content['gender_' . strtolower(postRequestParameter('gender'))] = ' selected="selected"';

			// Init receive selection
			$content['receive_warnings_y'] = '';
			$content['receive_warnings_n'] = '';

			// Check for receive_warnings
			$content['receive_warnings_' . strtolower(postRequestParameter('receive_warnings'))] = ' selected="selected"';
			$OUT = '';

			// Errors found?
			if (count($formErrors) > 0) {
				$OUT = displayMessage('{--SPONSOR_REGISTER_SOMETHING_MISSING--}', true);
				$OUT .= '<ol>';
				foreach ($formErrors as $error) {
					$OUT .= '<li>' . $error . '</li>';
				} // END - foreach

				$OUT .= '</ol>';
			} // END - if

			$content['form_errors'] = $OUT;

			// @TODO Maybe a default referal id?
			$content['refid'] = 0;

			// Is the referal id valid?
			if ((isPostRequestParameterSet('refid')) && (isValidUserId(postRequestParameter('refid')))) {
				// Transfer referal id
				$content['refid'] = bigintval(postRequestParameter('refid'));
			} // END - if
		} // END - if

		// Display registration form
		loadTemplate('guest_sponsor_reg', false, $content);
	} else {
		// Nothing added so far
		displayMessage('{--SPONSOR_PAYMENT_LIST_IS_EMPTY--}');
	}

	// Free memory
	SQL_FREERESULT($result);
}

// [EOF]
?>
